==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/apprunner_service/ApprunnerServiceObservabilityConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.apprunner_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:51.618Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.apprunnerService.ApprunnerServiceObservabilityConfiguration")
@software.amazon.jsii.Jsii.Proxy(ApprunnerServiceObservabilityConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ApprunnerServiceObservabilityConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#observability_configuration_arn ApprunnerService#observability_configuration_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getObservabilityConfigurationArn();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#observability_enabled ApprunnerService#observability_enabled}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getObservabilityEnabled();

    /**
     * @return a {@link Builder} of {@link ApprunnerServiceObservabilityConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ApprunnerServiceObservabilityConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ApprunnerServiceObservabilityConfiguration> {
        java.lang.String observabilityConfigurationArn;
        java.lang.Object observabilityEnabled;

        /**
         * Sets the value of {@link ApprunnerServiceObservabilityConfiguration#getObservabilityConfigurationArn}
         * @param observabilityConfigurationArn Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#observability_configuration_arn ApprunnerService#observability_configuration_arn}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder observabilityConfigurationArn(java.lang.String observabilityConfigurationArn) {
            this.observabilityConfigurationArn = observabilityConfigurationArn;
            return this;
        }

        /**
         * Sets the value of {@link ApprunnerServiceObservabilityConfiguration#getObservabilityEnabled}
         * @param observabilityEnabled Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#observability_enabled ApprunnerService#observability_enabled}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder observabilityEnabled(java.lang.Boolean observabilityEnabled) {
            this.observabilityEnabled = observabilityEnabled;
            return this;
        }

        /**
         * Sets the value of {@link ApprunnerServiceObservabilityConfiguration#getObservabilityEnabled}
         * @param observabilityEnabled Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/apprunner_service#observability_enabled ApprunnerService#observability_enabled}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder observabilityEnabled(com.hashicorp.cdktf.IResolvable observabilityEnabled) {
            this.observabilityEnabled = observabilityEnabled;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApprunnerServiceObservabilityConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ApprunnerServiceObservabilityConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ApprunnerServiceObservabilityConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ApprunnerServiceObservabilityConfiguration {
        private final java.lang.String observabilityConfigurationArn;
        private final java.lang.Object observabilityEnabled;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.observabilityConfigurationArn = software.amazon.jsii.Kernel.get(this, "observabilityConfigurationArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.observabilityEnabled = software.amazon.jsii.Kernel.get(this, "observabilityEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.observabilityConfigurationArn = java.util.Objects.requireNonNull(builder.observabilityConfigurationArn, "observabilityConfigurationArn is required");
            this.observabilityEnabled = java.util.Objects.requireNonNull(builder.observabilityEnabled, "observabilityEnabled is required");
        }

        @Override
        public final java.lang.String getObservabilityConfigurationArn() {
            return this.observabilityConfigurationArn;
        }

        @Override
        public final java.lang.Object getObservabilityEnabled() {
            return this.observabilityEnabled;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("observabilityConfigurationArn", om.valueToTree(this.getObservabilityConfigurationArn()));
            data.set("observabilityEnabled", om.valueToTree(this.getObservabilityEnabled()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.apprunnerService.ApprunnerServiceObservabilityConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ApprunnerServiceObservabilityConfiguration.Jsii$Proxy that = (ApprunnerServiceObservabilityConfiguration.Jsii$Proxy) o;

            if (!observabilityConfigurationArn.equals(that.observabilityConfigurationArn)) return false;
            return this.observabilityEnabled.equals(that.observabilityEnabled);
        }

        @Override
        public final int hashCode() {
            int result = this.observabilityConfigurationArn.hashCode();
            result = 31 * result + (this.observabilityEnabled.hashCode());
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/apprunner_service/ApprunnerServiceObservabilityConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.apprunner_service;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:07.404Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.apprunnerService.ApprunnerServiceObservabilityConfiguration")
@software.amazon.jsii.Jsii.Proxy(ApprunnerServiceObservabilityConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ApprunnerServiceObservabilityConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#observability_enabled ApprunnerService#observability_enabled}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getObservabilityEnabled();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#observability_configuration_arn ApprunnerService#observability_configuration_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getObservabilityConfigurationArn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ApprunnerServiceObservabilityConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ApprunnerServiceObservabilityConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ApprunnerServiceObservabilityConfiguration> {
        java.lang.Object observabilityEnabled;
        java.lang.String observabilityConfigurationArn;

        /**
         * Sets the value of {@link ApprunnerServiceObservabilityConfiguration#getObservabilityEnabled}
         * @param observabilityEnabled Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#observability_enabled ApprunnerService#observability_enabled}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder observabilityEnabled(java.lang.Boolean observabilityEnabled) {
            this.observabilityEnabled = observabilityEnabled;
            return this;
        }

        /**
         * Sets the value of {@link ApprunnerServiceObservabilityConfiguration#getObservabilityEnabled}
         * @param observabilityEnabled Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#observability_enabled ApprunnerService#observability_enabled}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder observabilityEnabled(com.hashicorp.cdktf.IResolvable observabilityEnabled) {
            this.observabilityEnabled = observabilityEnabled;
            return this;
        }

        /**
         * Sets the value of {@link ApprunnerServiceObservabilityConfiguration#getObservabilityConfigurationArn}
         * @param observabilityConfigurationArn Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/apprunner_service#observability_configuration_arn ApprunnerService#observability_configuration_arn}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder observabilityConfigurationArn(java.lang.String observabilityConfigurationArn) {
            this.observabilityConfigurationArn = observabilityConfigurationArn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ApprunnerServiceObservabilityConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ApprunnerServiceObservabilityConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ApprunnerServiceObservabilityConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ApprunnerServiceObservabilityConfiguration {
        private final java.lang.Object observabilityEnabled;
        private final java.lang.String observabilityConfigurationArn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.observabilityEnabled = software.amazon.jsii.Kernel.get(this, "observabilityEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.observabilityConfigurationArn = software.amazon.jsii.Kernel.get(this, "observabilityConfigurationArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.observabilityEnabled = java.util.Objects.requireNonNull(builder.observabilityEnabled, "observabilityEnabled is required");
            this.observabilityConfigurationArn = builder.observabilityConfigurationArn;
        }

        @Override
        public final java.lang.Object getObservabilityEnabled() {
            return this.observabilityEnabled;
        }

        @Override
        public final java.lang.String getObservabilityConfigurationArn() {
            return this.observabilityConfigurationArn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("observabilityEnabled", om.valueToTree(this.getObservabilityEnabled()));
            if (this.getObservabilityConfigurationArn() != null) {
                data.set("observabilityConfigurationArn", om.valueToTree(this.getObservabilityConfigurationArn()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.apprunnerService.ApprunnerServiceObservabilityConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ApprunnerServiceObservabilityConfiguration.Jsii$Proxy that = (ApprunnerServiceObservabilityConfiguration.Jsii$Proxy) o;

            if (!observabilityEnabled.equals(that.observabilityEnabled)) return false;
            return this.observabilityConfigurationArn != null ? this.observabilityConfigurationArn.equals(that.observabilityConfigurationArn) : that.observabilityConfigurationArn == null;
        }

        @Override
        public final int hashCode() {
            int result = this.observabilityEnabled.hashCode();
            result = 31 * result + (this.observabilityConfigurationArn != null ? this.observabilityConfigurationArn.hashCode() : 0);
            return result;
        }
    }
}
